=======================
Deployer of AWS Lambdas
=======================


.. image:: https://img.shields.io/pypi/v/yald.svg
        :target: https://pypi.python.org/pypi/yald

.. image:: https://img.shields.io/travis/seanlynch/yald.svg
        :target: https://travis-ci.com/seanlynch/yald

.. image:: https://readthedocs.org/projects/yald/badge/?version=latest
        :target: https://yald.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Simple script for deploying code for a Lambda.


* Free software: Apache Software License 2.0
* Documentation: https://lambda-deployer.readthedocs.io.


Features
--------

* Deploy code through direct upload
* Deploy code via S3
* Assume a role before doing the above

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
